==> openshift-model-machineconfig-6.2.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigFluentImpl<A extends ContainerRuntimeConfigFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigFluent<A>{
  public ContainerRuntimeConfigFluentImpl() {
  }
  public ContainerRuntimeConfigFluentImpl(ContainerRuntimeConfig instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ContainerRuntimeConfigSpecBuilder spec;
  private ContainerRuntimeConfigStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ContainerRuntimeConfigFluent.MetadataNested<A> withNewMetadata() {
    return new ContainerRuntimeConfigFluentImpl.MetadataNestedImpl();
  }
  public ContainerRuntimeConfigFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ContainerRuntimeConfigFluentImpl.MetadataNestedImpl(item);
  }
  public ContainerRuntimeConfigFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ContainerRuntimeConfigFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ContainerRuntimeConfigFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfigSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ContainerRuntimeConfigSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ContainerRuntimeConfigSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ContainerRuntimeConfigSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ContainerRuntimeConfigFluent.SpecNested<A> withNewSpec() {
    return new ContainerRuntimeConfigFluentImpl.SpecNestedImpl();
  }
  public ContainerRuntimeConfigFluent.SpecNested<A> withNewSpecLike(ContainerRuntimeConfigSpec item) {
    return new ContainerRuntimeConfigFluentImpl.SpecNestedImpl(item);
  }
  public ContainerRuntimeConfigFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ContainerRuntimeConfigFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ContainerRuntimeConfigSpecBuilder().build());
  }
  public ContainerRuntimeConfigFluent.SpecNested<A> editOrNewSpecLike(ContainerRuntimeConfigSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfigStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ContainerRuntimeConfigStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ContainerRuntimeConfigStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ContainerRuntimeConfigStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ContainerRuntimeConfigFluent.StatusNested<A> withNewStatus() {
    return new ContainerRuntimeConfigFluentImpl.StatusNestedImpl();
  }
  public ContainerRuntimeConfigFluent.StatusNested<A> withNewStatusLike(ContainerRuntimeConfigStatus item) {
    return new ContainerRuntimeConfigFluentImpl.StatusNestedImpl(item);
  }
  public ContainerRuntimeConfigFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ContainerRuntimeConfigFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ContainerRuntimeConfigStatusBuilder().build());
  }
  public ContainerRuntimeConfigFluent.StatusNested<A> editOrNewStatusLike(ContainerRuntimeConfigStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigFluentImpl that = (ContainerRuntimeConfigFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ContainerRuntimeConfigFluent.MetadataNested<N>> implements ContainerRuntimeConfigFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ContainerRuntimeConfigSpecFluentImpl<ContainerRuntimeConfigFluent.SpecNested<N>> implements ContainerRuntimeConfigFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ContainerRuntimeConfigSpec item) {
      this.builder = new ContainerRuntimeConfigSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ContainerRuntimeConfigSpecBuilder(this);
    }
    ContainerRuntimeConfigSpecBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ContainerRuntimeConfigStatusFluentImpl<ContainerRuntimeConfigFluent.StatusNested<N>> implements ContainerRuntimeConfigFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ContainerRuntimeConfigStatus item) {
      this.builder = new ContainerRuntimeConfigStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ContainerRuntimeConfigStatusBuilder(this);
    }
    ContainerRuntimeConfigStatusBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-6.7.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigFluentImpl<A extends ContainerRuntimeConfigFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigFluent<A>{
  public ContainerRuntimeConfigFluentImpl() {
  }
  public ContainerRuntimeConfigFluentImpl(ContainerRuntimeConfig instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ContainerRuntimeConfigSpecBuilder spec;
  private ContainerRuntimeConfigStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ContainerRuntimeConfigFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ContainerRuntimeConfigFluentImpl.MetadataNestedImpl();
  }
  public ContainerRuntimeConfigFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ContainerRuntimeConfigFluentImpl.MetadataNestedImpl(item);
  }
  public ContainerRuntimeConfigFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ContainerRuntimeConfigFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ContainerRuntimeConfigFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfigSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ContainerRuntimeConfigSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ContainerRuntimeConfigSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ContainerRuntimeConfigSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ContainerRuntimeConfigFluentImpl.SpecNested<A> withNewSpec() {
    return new ContainerRuntimeConfigFluentImpl.SpecNestedImpl();
  }
  public ContainerRuntimeConfigFluentImpl.SpecNested<A> withNewSpecLike(ContainerRuntimeConfigSpec item) {
    return new ContainerRuntimeConfigFluentImpl.SpecNestedImpl(item);
  }
  public ContainerRuntimeConfigFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ContainerRuntimeConfigFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ContainerRuntimeConfigSpecBuilder().build());
  }
  public ContainerRuntimeConfigFluentImpl.SpecNested<A> editOrNewSpecLike(ContainerRuntimeConfigSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfigStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ContainerRuntimeConfigStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ContainerRuntimeConfigStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ContainerRuntimeConfigStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ContainerRuntimeConfigFluentImpl.StatusNested<A> withNewStatus() {
    return new ContainerRuntimeConfigFluentImpl.StatusNestedImpl();
  }
  public ContainerRuntimeConfigFluentImpl.StatusNested<A> withNewStatusLike(ContainerRuntimeConfigStatus item) {
    return new ContainerRuntimeConfigFluentImpl.StatusNestedImpl(item);
  }
  public ContainerRuntimeConfigFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ContainerRuntimeConfigFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ContainerRuntimeConfigStatusBuilder().build());
  }
  public ContainerRuntimeConfigFluentImpl.StatusNested<A> editOrNewStatusLike(ContainerRuntimeConfigStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerRuntimeConfigFluentImpl that = (ContainerRuntimeConfigFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ContainerRuntimeConfigFluentImpl.MetadataNested<N>> implements ContainerRuntimeConfigFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ContainerRuntimeConfigSpecFluentImpl<ContainerRuntimeConfigFluentImpl.SpecNested<N>> implements ContainerRuntimeConfigFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ContainerRuntimeConfigSpec item) {
      this.builder = new ContainerRuntimeConfigSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ContainerRuntimeConfigSpecBuilder(this);
    }
    ContainerRuntimeConfigSpecBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ContainerRuntimeConfigStatusFluentImpl<ContainerRuntimeConfigFluentImpl.StatusNested<N>> implements ContainerRuntimeConfigFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ContainerRuntimeConfigStatus item) {
      this.builder = new ContainerRuntimeConfigStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ContainerRuntimeConfigStatusBuilder(this);
    }
    ContainerRuntimeConfigStatusBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
